import 'package:flutter/widgets.dart';

extension MainAxisAlignmentExtension on MainAxisAlignment {
  /// Converts MainAxisAlignment to a WrapAlignment
  ///
  /// This is used by the library to convert a Row or Column into a Wrap and
  /// preserve the MainAxisAlignment property. This can be used elsewhere but
  /// that is unlikely.
  WrapAlignment wrapAlignment() {
    switch (this) {
      case MainAxisAlignment.spaceBetween:
        return WrapAlignment.spaceBetween;
      case MainAxisAlignment.spaceEvenly:
        return WrapAlignment.spaceEvenly;
      case MainAxisAlignment.spaceAround:
        return WrapAlignment.spaceAround;
      case MainAxisAlignment.center:
        return WrapAlignment.center;
      case MainAxisAlignment.start:
        return WrapAlignment.start;
      case MainAxisAlignment.end:
        return WrapAlignment.end;
      default:
        return WrapAlignment.center;
    }
  }
}

extension CrossAxisAlignmentExtension on CrossAxisAlignment {
  /// Converts CrossAxisAlignment to a WrapCrossAlignment
  ///
  /// This is used by the library to convert a Row or Column into a Wrap and
  /// preserve the CrossAxisAlignment property. This can be used elsewhere but
  /// that is unlikely.
  WrapCrossAlignment wrapCrossAlignment() {
    switch (this) {
      case CrossAxisAlignment.center:
        return WrapCrossAlignment.center;
      case CrossAxisAlignment.start:
        return WrapCrossAlignment.start;
      case CrossAxisAlignment.end:
        return WrapCrossAlignment.end;
      default:
        return WrapCrossAlignment.center;
    }
  }
}

extension WrapAlignmentExtension on WrapAlignment {
  /// Converts WrapAlignment to a MainAxisAlignment
  ///
  /// This is used by the library to convert a Wrap into a Row and Column and
  /// preserve the WrapAlignment property. This can be used elsewhere but that
  /// is unlikely.
  MainAxisAlignment mainAxisAlignment() {
    switch (this) {
      case WrapAlignment.spaceBetween:
        return MainAxisAlignment.spaceBetween;
      case WrapAlignment.spaceEvenly:
        return MainAxisAlignment.spaceEvenly;
      case WrapAlignment.spaceAround:
        return MainAxisAlignment.spaceAround;
      case WrapAlignment.center:
        return MainAxisAlignment.center;
      case WrapAlignment.start:
        return MainAxisAlignment.start;
      case WrapAlignment.end:
        return MainAxisAlignment.end;
      default:
        return MainAxisAlignment.center;
    }
  }
}

extension WrapCrossAlignmentExtension on WrapCrossAlignment {
  /// Converts WrapCrossAlignment to a CrossAxisAlignment
  ///
  /// This is used by the library to convert a Wrap into a Row and Column and
  /// preserve the WrapCrossAlignment property. This can be used elsewhere but
  /// that is unlikely.
  CrossAxisAlignment crossAxisAlignment() {
    switch (this) {
      case WrapCrossAlignment.center:
        return CrossAxisAlignment.center;
      case WrapCrossAlignment.start:
        return CrossAxisAlignment.start;
      case WrapCrossAlignment.end:
        return CrossAxisAlignment.end;
      default:
        return CrossAxisAlignment.center;
    }
  }
}
