import 'package:flutter/material.dart';

extension ExtendedString on String {
  /// Gets Color from a hex string
  ///
  /// There is an optional parameter to give opacity from 0-255 (Transparent to
  /// Opaque) which is set to fully opaque by default. The string can be any
  /// case but should be start with an '#' and have 6 hexadecimal characters.
  /// To use it:
  /// ```dart
  /// '#FFFFFF'.hexColor();
  /// ```
  Color hexColor({int opacity = 255}) {
    return Color(int.parse(
        ((opacity % 256).toRadixString(16) + this.toLowerCase())
            .replaceAll('#', ''),
        radix: 16));
  }
}

extension ExtendedColor on Color {
  /// Gets Hex String from a Color
  ///
  /// There is an optional parameter to show opacity from 0-255 which is set to
  /// false by default. the string will be lower case and will start with an '#'
  /// and have 6 hexadecimal characters if opacity is false and 8 characters if
  /// opacity is true.
  /// To use it:
  /// ```dart
  /// Colors.red.hexString();
  /// ```
  String hexString({bool showOpacity = false}) {
    return '#' + this.value.toRadixString(16).substring(showOpacity ? 0 : 2);
  }
}
